import { Injectable } from '@angular/core';
import { Router } from '@angular/router';

import { Effect, Actions, ofType } from '@ngrx/effects';
import { Action } from '@ngrx/store';

import { Observable } from 'rxjs/Observable';
import { of } from 'rxjs/observable/of';

import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/exhaustMap';
import 'rxjs/add/operator/switchMap';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/take';

import { RPCClientError } from '@loafer/ng-rpc/protocol';

import { Probe } from '../../model';
import { ProbeService } from '../../service/probe.service';

import {
  Modify,
  ModifySuccess,
  ModifyFailure,
  ActionType
} from './modify.action';

@Injectable()
export class Effects {

  constructor(
    private actions$: Actions,
    private probeService: ProbeService,
    private router: Router
  ) { }

  @Effect()
  modify$: Observable<Action> = this.actions$
    .ofType(ActionType.Modify)
    .map((action: Modify) => action.payload)
    .switchMap(payload => this.probeService.modify(payload))
    .map(probe => {
      return new ModifySuccess(probe);
    })
    .catch((error: RPCClientError) => {
      return of(new ModifyFailure(error));
    });
}
